@@ -222,7 +222,7 @@ r2stats = proto(
     add(graphBigFrame,  .$graphPanedGroup <- gpanedgroup(),expand=TRUE)
     add(.$graphPanedGroup, graphLeftGroup  <- ggroup(horizontal=FALSE),expand=TRUE)
     add(graphLeftGroup,                     glabel(.$translate("Plot type")))
-    add(graphLeftGroup, .$plotType       <- gdroplist(.$translate(c("Regression plot","Response distribution","Fitted and observed values","Quantile-quantile plot","Residuals distribution","Fitted values and residuals")),handler=.$plotCurrentModel,action="plot"))
+    add(graphLeftGroup, .$plotType       <- gdroplist(.$translate(c("Regression plot","Response distribution","Fitted and observed values","Quantile-quantile plot","Residuals distribution","Fitted values and residuals","Quantile residuals")),handler=.$plotCurrentModel,action="plot"))
     add(graphLeftGroup,  graphNb         <- gnotebook(),expand=TRUE)
     add(graphNb,         graphModelGroup <- ggroup(horizontal=FALSE),label=.$translate("Model"),expand=TRUE)
     add(graphModelGroup,.$graphModelList <- gtable(.$getModelList()),expand=TRUE)
@@ -248,9 +248,9 @@ r2stats = proto(
     add(addGroup, layout2 <- glayout(),expand=TRUE)
     layout2[1,1] <- .$addData <- gcheckbox(.$translate("Data"),checked=TRUE,handler=.$plotCurrentModel,action="plot")
     layout2[2,1] <- .$addModel <- gcheckbox(.$translate("Model"),checked=TRUE,handler=.$plotCurrentModel,action="plot")
-    layout2[3,1] <- .$addCondMeans <- gcheckbox(.$translate("Conditional means"),checked=FALSE,handler=.$plotCurrentModel,action="plot")
+    layout2[3,1] <- .$addCondMeans <- gcheckbox(.$translate("Conditional\nmeans"),checked=FALSE,handler=.$plotCurrentModel,action="plot")
     layout2[4,1] <- .$addRandCurves <- gcheckbox(.$translate("Random curves"),checked=TRUE,handler=.$plotCurrentModel,action="plot")
-    layout2[1,2] <- .$addRefLine <- gcheckbox(.$translate("Reference line"),handler=.$plotCurrentModel,action="plot")
+    layout2[1,2] <- .$addRefLine <- gcheckbox(.$translate("Reference\nline"),handler=.$plotCurrentModel,action="plot")
     layout2[2,2] <- .$addGrid <- gcheckbox(.$translate("Grid"),handler=.$plotCurrentModel,action="plot")
     layout2[3,2] <- .$addNoise <- gcheckbox(.$translate("Noise"),handler=.$plotCurrentModel,action="plot")
     layout2[4,2] <- .$addSmooth <- gcheckbox(.$translate("Smoothing"),handler=.$plotCurrentModel,action="plot")
